import argparse, glob, os, os.path, re

__all__ = ['compact','expand','rename']

def compact(font):
	d,f,x,s,b,i,t = compact.e(font).groups()
	return f'{d}{f}-{5+compact.x[x]*compact.s[s]}{compact.b[b]}{compact.i[i]}.{t}'

compact.e = re.compile(r'(.*[/\\])?(.+?)(?:(Semi|Extra|Ultra)?(Condensed|Extended))?-'
	r'(Hairline|Thin|ExtraLight|Light|Regular|Medium|SemiBold|Bold|ExtraBold|Black|Heavy)?'
	r'(Italic|Oblique)?\.(otf|ttf|woff2)', re.M).fullmatch
compact.x = {'Semi':1, None:2, 'Extra':3, 'Ultra':4}
compact.s = {'Condensed':-1, None:0, 'Extended':1}
compact.b = {'Hairline':0, 'Thin':1, 'ExtraLight':2, 'Light':3, None:4, 'Regular':4,
	'Medium':5, 'SemiBold':6, 'Bold':7, 'ExtraBold':8, 'Black':9, 'Heavy':9}
compact.i = {None:'', 'Italic':'i', 'Oblique':'o'}

def expand(font):
	d,f,s,b,i,t = expand.e(font).groups()
	s,b = int(s)-5, int(b)
	return f'''{d}{f}{expand.x[abs(s)]}{'Condensed' if s<0 else 'Extended' if s>0
		else ''}-{'' if b==4 and i else expand.b[b]}{expand.i[i]}.{t}'''

expand.e = re.compile(r'^(.*[/\\])?(.+?)-(\d)(\d)([io]?)\.(otf|ttf|woff2)', re.M).fullmatch
expand.x = ['', 'Semi', '', 'Extra', 'Ultra']
expand.b = ['Hairline', 'Thin', 'ExtraLight', 'Light', 'Regular',
	'Medium', 'SemiBold', 'Bold', 'ExtraBold', 'Black']
expand.i = {'':'', 'i':'Italic', 'o':'Oblique'}

def fsbi(files, list=False, restore=False, write=False):
	r,x = [], expand if restore else compact
	for f in sum([glob.glob(f'{f}/*' if os.path.isdir(f) else f) for f in files], []):
		try:
			r.append((f, (n:=x(f)) ))
			if list: print(f'{f} -> {n}')
			if write: os.rename(f,n)
		except:
			pass
	return r

def main():
	a = argparse.ArgumentParser(usage='fsbi [-lrw] [file] ...', add_help=False)
	a.add_argument('file', nargs='*', default=['*'], help='file or dir [*]')
	a.add_argument('-h', action='help', help=argparse.SUPPRESS)
	a.add_argument('-l', action='store_true', help='list [default]')
	a.add_argument('-r', action='store_true', help='restore')
	a.add_argument('-w', action='store_true', help='write')
	a = a.parse_args()
	fsbi(a.file, a.l or not a.w, a.r, a.w)

if __name__ == '__main__':
	main()


from setuptools import setup

description = '''\
`fsbi` renames font files in a compact, well alphabetically ordered way rather than the usual long and disordered notation. `fsbi -r` restores the original notation.

# Help

	usage: fsbi [-lrw] [file] ...
	
	positional arguments:
	  file  file or dir [*]
	
	options:
	  -l    list [default]
	  -r    restore
	  -w    write

# Compact

	fsbi

	Barlow-Bold.ttf -> Barlow-57.ttf
	Barlow-BoldItalic.ttf -> Barlow-57i.ttf
	BarlowCondensed-ExtraLight.ttf -> Barlow-32.ttf
	BarlowCondensed-ExtraLightItalic.ttf -> Barlow-32i.ttf

# Restore

	fsbi -r

	Barlow-32.ttf -> BarlowCondensed-ExtraLight.ttf
	Barlow-32i.ttf -> BarlowCondensed-ExtraLightItalic.ttf
	Barlow-57.ttf -> Barlow-Bold.ttf
	Barlow-57i.ttf -> Barlow-BoldItalic.ttf

# Python

	import fsbi
	fsbi.compact(font)
	fsbi.expand(font)
	fsbi.rename(files, list=False, restore=False, write=False)

# Values

| | Stretch | Weight
| :-: | :-: | :-:
| 0 | | Hairline
| 1 | UltraCondensed | Thin
| 2 | ExtraCondensed | ExtraLight
| 3 | Condensed | Light
| 4 | SemiCondensed | Regular
| 5 | Normal | Medium
| 6 | SemiExtended | SemiBold
| 7 | Extended | Bold
| 8 | ExtraExtended | ExtraBold
| 9 | UltraExtended | Black'''

setup(
	name = 'fsbi',
	version = '0.1',
	description = 'Font Stretch Bold Italic',
	long_description = description,
	long_description_content_type = 'text/markdown',
	license = 'MIT',
	url = 'http://phyl.io/?page=fsbi.html',
	author = 'Philippe Kappel',
	author_email = 'philippe.kappel@gmail.com',
	keywords = 'font',
	classifiers = [
		'Development Status :: 3 - Alpha',
		'Environment :: Console',
		'Intended Audience :: Developers',
		'Intended Audience :: End Users/Desktop',
		'Intended Audience :: System Administrators',
		'License :: OSI Approved :: MIT License',
		'Natural Language :: English',
		'Operating System :: OS Independent',
		'Programming Language :: Python :: 3',
		'Topic :: System :: Console Fonts',
		'Topic :: Text Processing :: Fonts',
		'Topic :: Utilities'],
	packages = ['fsbi'],
	entry_points = {'console_scripts': ['fsbi = fsbi:main']}
)